<?php
namespace App\Http\Controllers;

use App\Jobs\UploadedFile;
use App\Models\User;
use Illuminate\Support\Facades\Auth;
use App\Models\File;
use App\Models\Task;
use Illuminate\Support\Facades\Storage;
use Illuminate\Http\Request;

class UserController extends Controller
{
    public function dashboard()
    {
        return view('user.dashboard');
    }


    public function assignedTasks()
    {
        $user = User::find(auth()->id());
        $tasks = $user->assignedTasks()->with(['project', 'creator'])->get();

        return view('user.assigned-task', compact('tasks'));
    }

    public function uploadFile(Request $request, Task $task)
    {
        // dd($request->task_file);
        $request->validate([
            'task_file' => 'required|file|mimes:jpg,jpeg,png,pdf,doc,docx,xlsx,xls,ppt,pptx,txt|max:10240', 
        ]);

        $file = $request->file('task_file');
        $tempPath = $file->storeAs('temp', $file->getClientOriginalName());

        dispatch(new UploadedFile(
            storage_path("app/{$tempPath}"),
            $file->getClientOriginalName(),
            $task->id,
            auth()->id()
        ));

        return back()->with('success', 'File is being uploaded in background.');
    }

        public function notifications()
        {
            $user = auth()->user();
            $user->unreadNotifications->markAsRead();
            $notifications = $user->notifications;

            return view('user.notifications', compact('notifications'));
        }

}
