<?php

namespace App\Jobs;

use App\Models\File;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Storage;

class UploadedFile implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;
    public $tempPath, $originalName, $taskId, $uploadedBy;

    public function __construct($tempPath, $originalName, $taskId, $uploadedBy) {
        $this->tempPath = $tempPath;
        $this->originalName = $originalName;
        $this->taskId = $taskId;
        $this->uploadedBy = $uploadedBy;
    }

    public function handle() {
        $fileContent = file_get_contents($this->tempPath);
        $finalPath = 'task_uploads/' . uniqid() . '_' . $this->originalName;
        Storage::disk('public')->put($finalPath, $fileContent);

        \App\Models\File::create([
            'task_id' => $this->taskId,
            'file_path' => $finalPath,
            'original_name' => $this->originalName,
            'uploaded_by' => $this->uploadedBy,
        ]);

        unlink($this->tempPath);
    }
}