<?php

namespace App\Providers;

use Illuminate\Cache\RateLimiting\Limit;
use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\RateLimiter;
use Illuminate\Support\Facades\Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * The path to your application's "home" route.
     *
     * Typically, users are redirected here after authentication.
     *
     * @var string
     */
    public const ADMINHOME = '/admin/dashboard';
    public const USERHOME = '/user/dashboard';


    /**
     * Define your route model bindings, pattern filters, and other route configuration.
     */
    public function boot(): void
    {
        RateLimiter::for('api', function (Request $request) {
            return Limit::perMinute(60)->by($request->user()?->id ?: $request->ip());
        });

        RateLimiter::for('admin-web',function(Request $request){
            $user=$request->user();
            if($user && $user->role->name === 'admin'){
                return Limit::perMinute(20)->by($user->id)->response(function(){
                    return response()->json([
                        'message' => 'Limit exceeded. Please wait before trying again.'
                    ], 429);
                });              
            }
            return Limit::perMinute(10)->by(optional($user)->id ? : $request->ip());
        });

        RateLimiter::for('upload-limit',function(Request $request){
            return Limit::perHour(3)->by(optional($request->user())->id ?: $request->ip())->response(function(){
                return response()->json([
                    'message'=>'Upload limit exceeded. Please wait before trying again.'
                ],429);
            });
        });

        $this->routes(function () {
            Route::middleware('api')
                ->prefix('api')
                ->group(base_path('routes/api.php'));

            Route::middleware('web')
                ->group(base_path('routes/web.php'));
        });
    }
}
